import es
import cfglib
import playerlib
import popuplib

from rankme import rankme

addonName = "topweapons"

topweapons = rankme.addons.registerAddon(addonName)
announce = topweapons.announce('weaponx', 5, '#greenrankME: #defaultType #teamtop \'weapon name\'#default or #teamweapon \'weapon name\'#default to view the statistics of a weapon.')

translations = topweapons.translate()
translations.addLanguageGroup('weapon rank command',
     "#defaultRank #green$position#default/#green$total#default: #team$player #defaultwith #green$kills $weapon#default kills.",
     'Displays a message showing a player the weapon\'s statistics.',
     {'$position' : 'The current weapon rank of the player', '$total' : 'The total amount of player ranked in this weapon', '$player' : 'The current player\'s name', '$kills' : 'The amount of kills made with this weapon', '$weapon' : 'The name of the viewed weapon'})

config = topweapons.config("""Gives your players the ability to check their weapon stats and
compare their positions with others. Provides additional commands.
 
To install this addon, enable it in the addons.txt file.
This config file does not interfere with the main config file.
 
Load the addon with: load_module topweapons""")

_weapon_command      = config.cvar("rankme_topweapons_command",            "top",                       "The prefix of the commands that should show top weapon stats (exp. topknife, topak47, etc.)")
_weapon_rank_command = config.cvar("rankme_topweapons_rank_command",       "me",                        "The suffix of the command for player's weapons statistics (exp. ak47me, knifeme, deagleme)")
_block_commands      = config.cvar("rankme_topweapons_blocked_weapons",    "flashbang, smokegrenade",   "The weapons which should not be tracked by the plugin")

config.write()

blocked_weapons = []
text = translations.getLanguageFile()
def load():
    """
    Fires when the script initializes. Creates the addon's most important
    variables and executes config files and other features.
    """
    config.execute()
    
    list = str(_block_commands).split(',')
    for i in list:
        blocked_weapons.append(i.strip())
    
def player_say(ev):
    """
    Event player_say
    
    Executes when a player writes any information in the chatbox.
    Provides the usual event variables to compare data.
    """
    
    userid = int(ev['userid'])
    args = ev['text']
    
    if ev['text'].startswith(str(_weapon_command)):
        topCommand(userid, args)
        
    elif ev['text'].endswith(str(_weapon_rank_command)):
        weaponCommand(userid, args)
    
def weaponCommand(userid, args):
    command = args.replace(str(_weapon_rank_command), '')
    
    weapon = command
    if weapon not in rankme.all_weapons:
        return
    
    if weapon in blocked_weapons:
        return
    
    steamid = rankme.getPlayer(userid).uniqueid
    position = rankme.database.getWeaponPosition(steamid, weapon)
    total = rankme.database.getTotalWeaponCount(weapon)
    kills = rankme.database.getWeaponStats(steamid, weapon)
    
    index = rankme.getPlayer(userid).index
    for userid in es.getUseridList():
        rankme.saytext2(userid, index, text('weapon rank command', {'position' : position, 'total' : total, 'player' : es.getplayername(userid), 'kills' : kills, 'weapon' : weapon}, playerlib.getPlayer(userid).get('lang')))
    
def topCommand(userid, args):
    top10 = False
    weapon = None
    
    args = args.split(' ')
    if len(args) != 1:
        return
    
   
    args = str(args[0]).replace(str(_weapon_command), '')
    for i in rankme.all_weapons:
        if args.endswith(i):
            weapon = i
            break
            
    if not weapon:
        return
    
    if weapon in blocked_weapons:
        return
    
    search = str(args).replace(weapon, '')
    if not search:
        topCommand(userid, str(_weapon_command) + '10' + weapon)
        return
    
    try:
        # Check if number is integer
        positionsearch = int(search)
        
    except:
        return
    
    
    if rankme.database.getTotalWeaponCount(weapon) < 10:
        es.tell(userid, '#green', 'Not enough players are ranked yet.')
        return
    
    if positionsearch < 10:
        topCommand(userid, str(_weapon_command) + '10' + weapon)
        return
    
    i = 1
    if positionsearch > rankme.database.getTotalWeaponCount(weapon):
        positionsearch = rankme.database.getTotalWeaponCount(weapon)
        
    allplayers = rankme.database.getWeaponTop(positionsearch - 10, weapon)
        
    if allplayers:
        i = 1
        top = popuplib.create('weapontop_%s_%s_%s' % (userid, int(positionsearch), weapon))
        top.addline('->1. Top (%s-%s) %s Players' % (int(positionsearch) - 9 if int(positionsearch) > 9 else 1, int(positionsearch), weapon.capitalize()))

        top.addline(' ')
        top.menuselect = topHandler
        for steamid, kills in allplayers:
            name = rankme.database.getPlayerName(steamid)
            name = str(name.encode('utf_8','replace'))
            totalkills = rankme.database.getKills(steamid)
            totaldeaths = rankme.database.getDeaths(steamid)
        
            kdr = rankme.convertKdr(totalkills, totaldeaths)
            if i < 11:
                if int(rankme.settings.points_system):
                    if int(positionsearch) < 11:
                        if i < 10:
                            #es.msg(str(positionsearch) + ',' + str(points) + ',' + str(name) + ',' + str(kdr))
                            top.addline('  0' + str(int(positionsearch) - 10+i) + '  %s  %s (KDR %s)' % (str(kills), str(name), str(kdr)))
                        else:
                            top.addline('  ' + str(int(positionsearch) - 10+i) + '  %s  %s (KDR %s)' % (str(kills), str(name), str(kdr)))
                    else:
                        top.addline('  ' + str(int(positionsearch) - 10+i) + '  %s  %s (KDR %s)' % (str(kills), str(name), str(kdr)))
                else:
                    if int(positionsearch) < 11:
                        if i < 10:
                            top.addline('  0' + str(int(positionsearch) - 10+i) + '  %s  %s (KDR %s)' % (str(kills), str(name), str(kdr)))
                        else:
                            top.addline('  ' + str(int(positionsearch) - 10+i) + '  %s  %s (KDR %s)' % (str(kills), str(name), str(kdr)))
                    else:
                        top.addline('  ' + str(int(positionsearch) - 10+i) + '  %s  %s (KDR %s)' % (str(kills), str(name), str(kdr)))
                    
                i += 1
                
            else:
                break
            
        top.addline(' ')
        if not int(positionsearch) < 11:
            top.addline('->8. Back')
            
        if not rankme.database.getTotalWeaponCount(weapon) < int(positionsearch):
            top.addline('->9. Next')
        top.addline('0. Close')
            
        top.send(userid)
    
def topHandler(userid, choice, popupid):
    # This function heandles the next and back button on the top list so
    # players can browse through the statistics.
    last_split = popupid.split('_')
    last_search = int(last_split[2])
    weapon = str(last_split[3])
    if choice == 8:
        if last_search < 0:
            topCommand(userid, str(_weapon_command) + '10' + weapon)
        
        elif last_search < 11:
            popuplib.send(popupid, userid)
        else:
            newsearch = int(last_search)-10
            if newsearch < 11:
                topCommand(userid, str(_weapon_command) + '10' + weapon)
                return
            topCommand(userid, str(_weapon_command) + str(newsearch) + weapon)
            
    elif choice == 9:
        if last_search >= rankme.database.getTotalWeaponCount(weapon):
            popuplib.send(popupid, userid)
        else:
            newsearch = int(last_search)+10
            if newsearch >= rankme.database.getTotalWeaponCount(weapon):
                topCommand(userid, str(_weapon_command) + str(rankme.database.getTotalWeaponCount(weapon)) + weapon)
                return
            topCommand(userid, str(_weapon_command) + str(newsearch) + weapon)
        
    

